@@ -87,10 +87,6 @@ sub _generate_initialize_object {
             $post_process .= "\$checks[$index]->($instance_slot)\n";
             $post_process .= "  or $attr_var->_throw_type_constraint_error($instance_slot, $constraint_var);\n";
         }
-        if($is_weak_ref){
-            $post_process  = "Scalar::Util::weaken($instance_slot) "
-                             . "if ref $instance_slot;\n";
-        }
 
         # build cde for an attribute
         if (defined $init_arg) {
@@ -151,6 +147,11 @@ sub _generate_initialize_object {
 
         $code .= "}\n" if defined $init_arg;
 
+        if($is_weak_ref){
+            $code .= "Scalar::Util::weaken($instance_slot) "
+                   . "if ref $instance_slot;\n";
+        }
+
         push @res, $code;
     }
 
@@ -232,7 +233,7 @@ Mouse::Meta::Method::Constructor - A Mouse method generator for constructors
 
 =head1 VERSION
 
-This document describes Mouse version 0.92
+This document describes Mouse version 0.93
 
 =head1 SEE ALSO
 
